Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CloudNodeSpec ¶
type CloudPodSpec ¶
type CloudPodSpec struct {
// only pod template is useful, ignore name, now we have not completely know the struct like
PodRef *v1.Pod
Workload *unstructured.Unstructured
Cpu resource.Quantity
Mem resource.Quantity
CpuLimit resource.Quantity
MemLimit resource.Quantity
Zone string
// v100,t4,amd,Default:intel
MachineArch string
Gpu resource.Quantity
PodChargeType string
// time span
TimeSpan uint64
// replicas, for pod value is 1, for workload, value is replicas of the workload spec
GoodsNum uint64
// serverless pod or not
Serverless bool
QoSClass v1.PodQOSClass
}
type NodeFilter ¶
type WorkloadRecommendedData ¶
type WorkloadRecommendedData struct {
RecommendedSpec CloudPodSpec
PercentRecommendedSpec *CloudPodSpec
MaxRecommendedSpec *CloudPodSpec
MaxMarginRecommendedSpec *CloudPodSpec
Containers map[string]*ContainerRecommendedData
}
Click to show internal directories.
Click to hide internal directories.